import java.lang.Math;

/**
 * Represents a grayscale pixel value
 * 
 * @author alchambers
 * @version spring2019
 */
public class Pixel{
    private static final int MAX_PIXEL_VAL = 255;
    private static final int MIN_PIXEL_VAL = 0;
    private int value;

    public Pixel(int initValue){
       checkAndSet(initValue);
    }
    
    public int getValue(){
        return value;
    }
    
    public void setValue(int newValue){
        checkAndSet(newValue);
    }

    public void invertIntensity(){
        int newValue = MAX_PIXEL_VAL - value;
        checkAndSet(newValue);
    }
    
    public void logIntensity(double coeff){
        int newValue = (int)(coeff*Math.log(value+1));
        checkAndSet(newValue);
    }
    
    public void powerLawIntensity(double coeff, double gamma){
        int newValue = (int)(coeff* Math.pow(value, gamma));
        checkAndSet(newValue);
    }
    
    private void checkAndSet(int newValue){
       if(newValue < MIN_PIXEL_VAL){
            value = MIN_PIXEL_VAL;
        }
        else if(newValue > MAX_PIXEL_VAL){
            value = MAX_PIXEL_VAL;
        }
        else{
            value = newValue;
        }  
    }
}
